Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(633)

Unified Diff: sdk/lib/async/stream.dart

Issue 12537009: Rename XMatching to XWhere. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Merge and rebuild dom libraries. Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/compiler/implementation/lib/js_array.dart ('k') | sdk/lib/collection/collections.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/async/stream.dart
diff --git a/sdk/lib/async/stream.dart b/sdk/lib/async/stream.dart
index ac0ec79ac739adfb2995dc5cf5651c5087c43ef4..8ac0541908681a94f19156baf1051b542fafbdaa 100644
--- a/sdk/lib/async/stream.dart
+++ b/sdk/lib/async/stream.dart
@@ -643,7 +643,7 @@ abstract class Stream<T> {
* with no [defaultValue] function provided, the future will receive an
* error.
*/
- Future<T> firstMatching(bool test(T value), {T defaultValue()}) {
+ Future<T> firstWhere(bool test(T value), {T defaultValue()}) {
_FutureImpl<T> future = new _FutureImpl<T>();
StreamSubscription subscription;
subscription = this.listen(
@@ -677,11 +677,11 @@ abstract class Stream<T> {
/**
* Finds the last element in this stream matching [test].
*
* As [firstMatching], except that the last matching element is found.
* That means that the result cannot be provided before this stream
* is done.
*/
- Future<T> lastMatching(bool test(T value), {T defaultValue()}) {
+ Future<T> lastWhere(bool test(T value), {T defaultValue()}) {
_FutureImpl<T> future = new _FutureImpl<T>();
T result = null;
bool foundResult = false;
@@ -724,7 +724,7 @@ abstract class Stream<T> {
* Like [lastMatch], except that it is an error if more than one
* matching element occurs in the stream.
*/
- Future<T> singleMatching(bool test(T value)) {
+ Future<T> singleWhere(bool test(T value)) {
_FutureImpl<T> future = new _FutureImpl<T>();
T result = null;
bool foundResult = false;
@@ -677,11 +677,11 @@ abstract class Stream<T> {
* Finds the last element in this stream matching [test].
*
- * As [firstMatching], except that the last matching element is found.
+ * As [firstWhere], except that the last matching element is found.
* That means that the result cannot be provided before this stream
* is done.
« no previous file with comments | « sdk/lib/_internal/compiler/implementation/lib/js_array.dart ('k') | sdk/lib/collection/collections.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698